{{/*
    EMS Device-Auth Proxy Set Headers ConfigMap
    A namespace-prefixed configmap that contains headers to add to auth calls
*/}}
{{- define "app-utils.deviceAuthProxySetHeadersConfigMap" -}}
{{ .Values.global.appsNamespace }}/ems-device-auth-proxy-set-headers
{{- end -}}

{{/*
    Annotations for Ingress resources for requests that need to be authenticated with EMS

    auth-cache disabled for now:
    nginx.ingress.kubernetes.io/auth-cache-key: $http_registration_id$http_device_guid
    nginx.ingress.kubernetes.io/auth-cache-duration: 200 400 401 5m
*/}}
{{- define "app-utils.externalDeviceIngressAuthAnnotations" -}}
nginx.ingress.kubernetes.io/auth-url: {{ include "app-utils.deviceAuthEndpoint" . }}
nginx.ingress.kubernetes.io/auth-proxy-set-headers: {{ include "app-utils.deviceAuthProxySetHeadersConfigMap" . }}
nginx.ingress.kubernetes.io/auth-response-headers: Device-Context, Org-Context, Wf-Ot-Traceid
{{- end -}}

{{- define "app-utils.externalDeviceIngressNonAuthAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.deviceIngressType | default "vdp-nginx-l7-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
      proxy_set_header X-Request-Context "";
      proxy_set_header X-User-Context "";
      add_header Content-Security-Policy "frame-ancestors 'self';" always;
      add_header Referrer-Policy "origin" always;
{{- end -}}

{{- define "app-utils.externalDeviceIngressAnnotations" -}}
{{ include "app-utils.externalDeviceIngressAuthAnnotations" . }}
{{ include "app-utils.externalDeviceIngressNonAuthAnnotations" . }}
{{- end -}}
