{{/*
    Annotations for Ingress resources for external requests without authentication. USE WITH CAUTION!
*/}}
{{- define "app-utils.externalUnauthenticatedAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.extIngressType | default "vdp-nginx-l7-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{/*
    Annotations for csr Ingress resources for requests without authentication. USE WITH CAUTION!
*/}}
{{- define "app-utils.csrUnauthenticatedAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.csrIngressType | default "vdp-nginx-l4-vmware" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}

{{/*
    Annotations for Ingress resources for internal requests without authentication
*/}}
{{- define "app-utils.internalIngress" -}}
kubernetes.io/ingress.class: {{ .Values.global.intIngressType | default "nginx-l4-int" }}
nginx.ingress.kubernetes.io/ssl-redirect: 'false'
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
{{- end -}}

{{/*
    Annotations for csp Ingress resources for requests without authentication. USE WITH CAUTION!
*/}}
{{- define "app-utils.cspUnauthenticatedAnnotations" -}}
kubernetes.io/ingress.class: {{ .Values.global.cspIngressType | default "vdp-nginx-l4-nlb-ext" }}
nginx.ingress.kubernetes.io/configuration-snippet: |
  proxy_set_header X-Request-Context "";
  proxy_set_header X-User-Context "";
  proxy_hide_header X-Request-Context;
  proxy_hide_header X-User-Context;
  add_header Content-Security-Policy "frame-ancestors 'self';" always;
  add_header Strict-Transport-Security "max-age=31536000; includeSubDomains" always;
  add_header Referrer-Policy "origin" always;
{{- end -}}
