#################################################################################
##### This is a shared file from helm/app-common. Use caution when editing! #####
#################################################################################

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "mdr-reporting-job.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Derive the image tag from the Chart version based on our scheme to pin them together
*/}}
{{- define "mdr-reporting-job.imageTag" -}}
{{ "" | regexReplaceAll "^\\d+.\\d+.\\d+-" .Chart.Version }}
{{- end -}}

{{/*
Derive the infra namespace
*/}}
{{- define "infraNamespace" -}}
{{ .Values.global.env }}-infra
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "mdr-reporting-job.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Expand the name of the chart.
*/}}
{{- define "mdr-reporting-job.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "mdr-reporting-job.selectorLabels" -}}
app.kubernetes.io/name: {{ include "mdr-reporting-job.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
#Adding stackid as label selector for grouping
{{- if .Values.wavefront }}
stack: {{ .Values.wavefront.stackId }}
{{- end }}
sbu.vmware.com/sguid: {{ include "app-utils.sguid" . }}
{{- end }}}

{{/*
Common labels
*/}}
{{- define "mdr-reporting-job.labels" -}}
helm.sh/chart: {{ include "mdr-reporting-job.chart" . }}
{{ include "mdr-reporting-job.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
#Adding service sguid as label for tagging pods.
sbu.vmware.com/sguid: {{ printf "%s" .Values.sguid | replace ":" "-" }}
{{- end }}


{{/*
Create the name of the service account to use
*/}}
{{- define "mdr-reporting-job.serviceAccountName" -}}
{{- if .Values.serviceAccount.create }}
{{- default (include "mdr-reporting-job.fullname" .) .Values.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.serviceAccount.name }}
{{- end }}
{{- end }}